@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-"""Simple program to exact 5x5 geoid seperations in EGM2008
+"""Simple program to exact 5x5 geoid separations in EGM2008
 from GeoidEval for use in geoidc"""
 
 import sys
