@@ -1,7 +1,7 @@
 /*
  * gpsdclient.c -- support functions for GPSD clients
  *
- * This file is Copyright (c) 2010-2018 by the GPSD project
+ * This file is Copyright 2010 by the GPSD project
  * SPDX-License-Identifier: BSD-2-clause
  */
 
@@ -36,7 +36,7 @@ static struct exportmethod_t exportmethods[] = {
  * Return a pointer to the buffer.
  *
  * deg_str_type:
- *   	deg_dd     : return DD.ddddddd[suffix]
+ *      deg_dd     : return DD.ddddddd[suffix]
  *      deg_ddmm   : return DD MM.mmmmmm'[suffix]
  *      deg_ddmmss : return DD MM' SS.sssss"[suffix]
  *
@@ -59,23 +59,23 @@ char *deg_to_str2(enum deg_str_type type, double f,
     const char *suffix = "";
 
     if (20 > buf_size) {
-	(void)strlcpy(buf, "Err", buf_size);
-	return buf;
+        (void)strlcpy(buf, "Err", buf_size);
+        return buf;
     }
 
     if (!isfinite(f) || 360.0 < fabs(f)) {
-	(void)strlcpy(buf, "n/a", buf_size);
-	return buf;
+        (void)strlcpy(buf, "n/a", buf_size);
+        return buf;
     }
 
     /* suffix? */
     if (0.0 > f) {
-	f = -f;
+        f = -f;
         if (NULL != suffix_neg) {
             suffix = suffix_neg;
         }
     } else if (NULL != suffix_pos) {
-	suffix = suffix_pos;
+        suffix = suffix_pos;
     }
 
     /* add rounding quanta */
@@ -86,51 +86,53 @@ char *deg_to_str2(enum deg_str_type type, double f,
     default:
         /* huh? */
         type = deg_dd;
-        /* FALLTHROUGH */
+        /* It's not worth battling fallthrough warnings just for two lines */
+        f += 0.5 * 1e-8;              /* round up */
+        break;
     case deg_dd:
-	/* DD.dddddddd */
-	f += 0.5 * 1e-8;              /* round up */
+        /* DD.dddddddd */
+        f += 0.5 * 1e-8;              /* round up */
         break;
     case deg_ddmm:
-	/* DD MM.mmmmmm */
-	f += (0.5 * 1e-6) / 60;       /* round up */
+        /* DD MM.mmmmmm */
+        f += (0.5 * 1e-6) / 60;       /* round up */
         break;
     case deg_ddmmss:
-	f += (0.5 * 1e-5) / 3600;     /* round up */
+        f += (0.5 * 1e-5) / 3600;     /* round up */
         break;
     }
     fmin = modf(f, &fdeg);
     deg = (int)fdeg;
     if (360 == deg) {
-	/* fix round-up roll-over */
-	deg = 0;
-	fmin = 0.0;
+        /* fix round-up roll-over */
+        deg = 0;
+        fmin = 0.0;
     }
 
     if (deg_dd == type) {
-	/* DD.dddddddd */
-	long frac_deg = (long)(fmin * 100000000.0);
+        /* DD.dddddddd */
+        long frac_deg = (long)(fmin * 100000000.0);
         /* cm level accuracy requires the %08ld */
-	(void)snprintf(buf, buf_size, "%3d.%08ld%s", deg, frac_deg, suffix);
-	return buf;
+        (void)snprintf(buf, buf_size, "%3d.%08ld%s", deg, frac_deg, suffix);
+        return buf;
     }
 
     fsec = modf(fmin * 60, &fmin);
     min = (int)fmin;
 
     if (deg_ddmm == type) {
-	/* DD MM.mmmmmm */
-	sec = (int)(fsec * 1000000.0);
-	(void)snprintf(buf, buf_size, "%3d %02d.%06d'%s", deg, min, sec,
+        /* DD MM.mmmmmm */
+        sec = (int)(fsec * 1000000.0);
+        (void)snprintf(buf, buf_size, "%3d %02d.%06d'%s", deg, min, sec,
                        suffix);
-	return buf;
+        return buf;
     }
     /* else DD MM SS.sss */
     fdsec = modf(fsec * 60.0, &fsec);
     sec = (int)fsec;
     dsec = (int)(fdsec * 100000.0);
     (void)snprintf(buf, buf_size, "%3d %02d' %02d.%05d\"%s", deg, min, sec,
-		   dsec, suffix);
+                   dsec, suffix);
 
     return buf;
 }
@@ -140,7 +142,7 @@ char *deg_to_str2(enum deg_str_type type, double f,
  * WARNING: Not thread safe.
  *
  * deg_str_type:
- *   	deg_dd     : return DD.ddddddd
+ *      deg_dd     : return DD.ddddddd
  *      deg_ddmm   : return DD MM.mmmmmm'
  *      deg_ddmmss : return DD MM' SS.sssss"
  *
@@ -173,16 +175,16 @@ char *deg_to_str(enum deg_str_type type, double f)
  *
  * In order check these environment vars:
  *    GPSD_UNITS one of:
- *            	imperial   = miles/feet
+ *              imperial   = miles/feet
  *              nautical   = knots/feet
  *              metric     = km/meters
  *    LC_MEASUREMENT
- *		en_US      = miles/feet
+ *              en_US      = miles/feet
  *              C          = miles/feet
  *              POSIX      = miles/feet
  *              [other]    = km/meters
  *    LANG
- *		en_US      = miles/feet
+ *              en_US      = miles/feet
  *              C          = miles/feet
  *              POSIX      = miles/feet
  *              [other]    = km/meters
@@ -194,32 +196,32 @@ enum unit gpsd_units(void)
     char *envu = NULL;
 
     if ((envu = getenv("GPSD_UNITS")) != NULL && *envu != '\0') {
-	if (0 == strcasecmp(envu, "imperial")) {
-	    return imperial;
-	}
-	if (0 == strcasecmp(envu, "nautical")) {
-	    return nautical;
-	}
-	if (0 == strcasecmp(envu, "metric")) {
-	    return metric;
-	}
-	/* unrecognized, ignore it */
+        if (0 == strcasecmp(envu, "imperial")) {
+            return imperial;
+        }
+        if (0 == strcasecmp(envu, "nautical")) {
+            return nautical;
+        }
+        if (0 == strcasecmp(envu, "metric")) {
+            return metric;
+        }
+        /* unrecognized, ignore it */
     }
     if (((envu = getenv("LC_MEASUREMENT")) != NULL && *envu != '\0')
-	|| ((envu = getenv("LANG")) != NULL && *envu != '\0')) {
-	if (strncasecmp(envu, "en_US", 5) == 0
-	    || strcasecmp(envu, "C") == 0 || strcasecmp(envu, "POSIX") == 0) {
-	    return imperial;
-	}
-	/* Other, must be metric */
-	return metric;
+        || ((envu = getenv("LANG")) != NULL && *envu != '\0')) {
+        if (strncasecmp(envu, "en_US", 5) == 0
+            || strcasecmp(envu, "C") == 0 || strcasecmp(envu, "POSIX") == 0) {
+            return imperial;
+        }
+        /* Other, must be metric */
+        return metric;
     }
     /* TODO: allow a compile time default here */
     return unspecified;
 }
 
-void gpsd_source_spec(const char *arg, struct fixsource_t *source)
 /* standard parsing of a GPS data source spec */
+void gpsd_source_spec(const char *arg, struct fixsource_t *source)
 {
     /* the casts attempt to head off a -Wwrite-strings warning */
     source->server = (char *)"localhost";
@@ -227,46 +229,46 @@ void gpsd_source_spec(const char *arg, struct fixsource_t *source)
     source->device = NULL;
 
     if (arg != NULL) {
-	char *colon1, *skipto, *rbrk;
-	source->spec = (char *)arg;
-	assert(source->spec != NULL);
+        char *colon1, *skipto, *rbrk;
+        source->spec = (char *)arg;
+        assert(source->spec != NULL);
 
-	skipto = source->spec;
-	if (*skipto == '[' && (rbrk = strchr(skipto, ']')) != NULL) {
-	    skipto = rbrk;
-	}
-	colon1 = strchr(skipto, ':');
+        skipto = source->spec;
+        if (*skipto == '[' && (rbrk = strchr(skipto, ']')) != NULL) {
+            skipto = rbrk;
+        }
+        colon1 = strchr(skipto, ':');
 
-	if (colon1 != NULL) {
-	    char *colon2;
-	    *colon1 = '\0';
-	    if (colon1 != source->spec) {
-		source->server = source->spec;
-	    }
-	    source->port = colon1 + 1;
-	    colon2 = strchr(source->port, ':');
-	    if (colon2 != NULL) {
-		*colon2 = '\0';
-		source->device = colon2 + 1;
-	    }
-	} else if (strchr(source->spec, '/') != NULL) {
-	    source->device = source->spec;
-	} else {
-	    source->server = source->spec;
-	}
+        if (colon1 != NULL) {
+            char *colon2;
+            *colon1 = '\0';
+            if (colon1 != source->spec) {
+                source->server = source->spec;
+            }
+            source->port = colon1 + 1;
+            colon2 = strchr(source->port, ':');
+            if (colon2 != NULL) {
+                *colon2 = '\0';
+                source->device = colon2 + 1;
+            }
+        } else if (strchr(source->spec, '/') != NULL) {
+            source->device = source->spec;
+        } else {
+            source->server = source->spec;
+        }
     }
 
     if (*source->server == '[') {
-	char *rbrk = strchr(source->server, ']');
-	++source->server;
-	if (rbrk != NULL)
-	    *rbrk = '\0';
+        char *rbrk = strchr(source->server, ']');
+        ++source->server;
+        if (rbrk != NULL)
+            *rbrk = '\0';
     }
 }
 
 
-char *maidenhead(double n, double e)
 /* lat/lon to Maidenhead */
+char *maidenhead(double lat, double lon)
 {
     /*
      * Specification at
@@ -275,7 +277,7 @@ char *maidenhead(double n, double e)
      * There's a fair amount of slop in how Maidenhead converters operate
      * that can make it look like this one is wrong.
      *
-     * 1. Many return caps for paces 5 and 6 when according to the spwec
+     * 1. Many return caps for paces 5 and 6 when according to the spec
      *    they should return smalls.
      *
      * 2. Some converters, including QGrid from which this code was originally
@@ -285,55 +287,122 @@ char *maidenhead(double n, double e)
      *    round down from the cast). If I'm reading the spec right it
      *    is not correct to do this.
      */
-    static char buf[7];
+    /* FIXME: convert lat/lon to integer seconds, then do all the
+     * math on integers */
+    static char buf[9];
 
     int t1;
-    e=e+180.0;
-    t1=(int)(e/20);
-    buf[0]=(char)t1+'A';
-    e-=(float)t1*20.0;
-    t1=(int)e/2;
-    buf[2]=(char)t1+'0';
-    e-=(float)t1*2;
-    buf[4]=(char)(int)(e*12.0)+'a';
 
-    n=n+90.0;
-    t1=(int)(n/10.0);
-    buf[1]=(char)t1+'A';
-    n-=(float)t1*10.0;
-    buf[3]=(char)n+'0';
-    n-=(int)n;
-    n*=24; // convert to 24 division
-    buf[5]=(char)(int)(n)+'a';
-    buf[6] = '\0';
+    /* longitude */
+    if (179.99999 < lon) {
+        /* force 180, just inside lon_sq 'R'
+         * otherwise we get illegal 'S' */
+        lon = 179.99999;
+    }
+
+    lon += 180.0;
+    // divide into 18 zones (fields) each 20 degrees lon
+    t1 = (int)(lon / 20);
+    buf[0] = (char)t1 + 'A';
+    if ('R' < buf[0]) {
+        /* A to R */
+        buf[0] = 'R';
+    }
+    lon -= (float)t1 * 20.0;
+
+    // divide into 10 zones (squares) each 2 degrees lon
+    t1 = (int)lon / 2;
+    buf[2] = (char)t1 + '0';
+    lon -= (float)t1 * 2;
+
+    // lon is now degrees
+    lon *= 60.0;
+
+    // divide into 24 zones (subsquares) each 5 minute (5/60 deg) lon
+    t1 = (int)(lon / 5);
+    buf[4] = (char) ((char)t1 + 'a');
+    lon -= (float)(t1 * 5);
+
+    // lon is now seconds
+    lon *= 60.0;
+
+    // divide into 10 zones (extended squares) each 30 seconds (5/600 deg) lon
+    t1 = (int)(lon / 30);
+    if (9 < t1) {
+        // ugh, floating point gunk.
+        t1 = 9;
+    }
+    buf[6] = (char) ((char)t1 + '0');
+
+    /* latitude */
+    if (89.99999 < lat) {
+        /* force 90 to just inside lat_sq 'R'
+         * otherwise we get illegal 'S' */
+        lat = 89.99999;
+    }
+
+    lat += 90.0;
+    // divide into 18 zones (fields) each 10 degrees lat
+    t1 = (int)(lat / 10.0);
+    buf[1] = (char)t1 + 'A';
+    if ('R' < buf[1]) {
+        /* A to R, North Pole is R */
+        buf[1] = 'R';
+    }
+    lat -= (float)t1 * 10.0;
+
+    // divide into 10 zones (squares) each 1 degrees lat
+    buf[3] = (char)lat + '0';
+    lat -= (int)lat;
+
+    // lat is now degrees
+    lat *= 60.0;
+
+    // divide into 24 zones (subsquares) each 2.5 minute (5/120 deg) lat
+    t1 = (int)(lat / 2.5);
+    buf[5] = (char)((char)t1 + 'a');
+    lat -= (float)(t1 * 2.5);
+
+    // lat is now seconds
+    lat *= 60.0;
+
+    // divide into 10 zones (extended squares) each 15 seconds (5/1200 deg) lat
+    t1 = (int)(lat / 15);
+    if (9 < t1) {
+        // ugh, floating point gunk.
+        t1 = 9;
+    }
+    buf[7] = (char) ((char)t1 + '0');
+
+    buf[8] = '\0';
 
     return buf;
 }
 
 #define NITEMS(x) (int)(sizeof(x)/sizeof(x[0])) /* from gpsd.h-tail */
 
-struct exportmethod_t *export_lookup(const char *name)
 /* Look up an available export method by name */
+struct exportmethod_t *export_lookup(const char *name)
 {
     struct exportmethod_t *mp, *method = NULL;
 
     for (mp = exportmethods;
-	 mp < exportmethods + NITEMS(exportmethods);
-	 mp++)
-	if (strcmp(mp->name, name) == 0)
-	    method = mp;
+         mp < exportmethods + NITEMS(exportmethods);
+         mp++)
+        if (strcmp(mp->name, name) == 0)
+            method = mp;
     return method;
 }
 
-void export_list(FILE *fp)
 /* list known export methods */
+void export_list(FILE *fp)
 {
     struct exportmethod_t *method;
 
     for (method = exportmethods;
-	 method < exportmethods + NITEMS(exportmethods);
-	 method++)
-	(void)fprintf(fp, "%s: %s\n", method->name, method->description);
+         method < exportmethods + NITEMS(exportmethods);
+         method++)
+        (void)fprintf(fp, "%s: %s\n", method->name, method->description);
 }
 
 struct exportmethod_t *export_default(void)
@@ -341,70 +410,5 @@ struct exportmethod_t *export_default(void)
     return (NITEMS(exportmethods) > 0) ? &exportmethods[0] : NULL;
 }
 
-/* Convert true heading to magnetic.  Taken from the Aviation
-   Formulary v1.43.  Valid to within two degrees within the
-   continiental USA except for the following airports: MO49 MO86 MO50
-   3K6 02K and KOOA.  AK correct to better than one degree.  Western
-   Europe correct to within 0.2 deg.
-
-   If you're not in one of these areas, I apologize, I don't have the
-   math to compute your varation.  This is obviously extremely
-   floating-point heavy, so embedded people, beware of using.
-
-   Note that there are issues with using magnetic heading.  This code
-   does not account for the possibility of travelling into or out of
-   an area of valid calculation beyond forcing the magnetic conversion
-   off.  A better way to communicate this to the user is probably
-   desirable (in case the don't notice the subtle change from "(mag)"
-   to "(true)" on their display).
- */
-float true2magnetic(double lat, double lon, double heading)
-{
-    /* Western Europe */
-    if ((lat > 36.0) && (lat < 68.0) && (lon > -10.0) && (lon < 28.0)) {
-	heading =
-	    (10.4768771667158 - (0.507385322418858 * lon) +
-	     (0.00753170031703826 * pow(lon, 2))
-	     - (1.40596203924748e-05 * pow(lon, 3)) -
-	     (0.535560699962353 * lat)
-	     + (0.0154348808069955 * lat * lon) -
-	     (8.07756425110592e-05 * lat * pow(lon, 2))
-	     + (0.00976887198864442 * pow(lat, 2)) -
-	     (0.000259163929798334 * lon * pow(lat, 2))
-	     - (3.69056939266123e-05 * pow(lat, 3)) + heading);
-    }
-    /* USA */
-    else if ((lat > 24.0) && (lat < 50.0) && (lon > 66.0) && (lon < 125.0)) {
-	lon = 0.0 - lon;
-	heading =
-	    ((-65.6811) + (0.99 * lat) + (0.0128899 * pow(lat, 2)) -
-	     (0.0000905928 * pow(lat, 3)) + (2.87622 * lon)
-	     - (0.0116268 * lat * lon) - (0.00000603925 * lon * pow(lat, 2)) -
-	     (0.0389806 * pow(lon, 2))
-	     - (0.0000403488 * lat * pow(lon, 2)) +
-	     (0.000168556 * pow(lon, 3)) + heading);
-    }
-    /* AK */
-    else if ((lat > 54.0) && (lon > 130.0) && (lon < 172.0)) {
-	lon = 0.0 - lon;
-	heading =
-	    (618.854 + (2.76049 * lat) - (0.556206 * pow(lat, 2)) +
-	     (0.00251582 * pow(lat, 3)) - (12.7974 * lon)
-	     + (0.408161 * lat * lon) + (0.000434097 * lon * pow(lat, 2)) -
-	     (0.00602173 * pow(lon, 2))
-	     - (0.00144712 * lat * pow(lon, 2)) +
-	     (0.000222521 * pow(lon, 3)) + heading);
-    } else {
-	/* We don't know how to compute magnetic heading for this
-	 * location. */
-	heading = NAN;
-    }
-
-    /* No negative headings. */
-    if (isfinite(heading) != 0 && heading < 0.0)
-	heading += 360.0;
-
-    return (heading);
-}
-
 /* gpsdclient.c ends here */
+// vim: set expandtab shiftwidth=4
