@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# This file is Copyright (c) 2010 by the GPSD project
+# This file is Copyright 2010 by the GPSD project
 # SPDX-License-Identifier: BSD-2-clause
 #
 # Never hand-hack what you can generate...
@@ -17,7 +17,7 @@ import sys
 
 #
 # Here is the information that makes it all work - attribute, type, and
-# defult information for all fields.  We generate a JSON
+# default information for all fields.  We generate a JSON
 # parser template spec. Doing it this way guarantees consistency.
 #
 # Notes on the fields:
@@ -948,7 +948,8 @@ def generate(spec):
             sys.stderr.write("buffered %s is not in base attributes of %s\n"
                              % (attr, initname))
             raise SystemExit(1)
-        elif attr not in outboard:
+
+        if attr not in outboard:
             report += "    char %s[JSON_VAL_MAX+1];\n" % attr
             outboard.append(attr)
 
@@ -1061,3 +1062,4 @@ if __name__ == '__main__':
 # Local Variables:
 # mode:python
 # End:
+# vim: set expandtab shiftwidth=4
