@@ -1,12 +1,12 @@
 /*
- * This file is Copyright (c) 2010-2018 by the GPSD project
+ * This file is Copyright 2010 by the GPSD project
  * SPDX-License-Identifier: BSD-2-clause
  */
 
 #include "gpsd_config.h"  /* must be before all includes */
 
-#include <string.h>
 #include <fcntl.h>
+#include <string.h>
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif /* HAVE_NETDB_H */
@@ -50,7 +50,7 @@
 #endif
 
 socket_t netlib_connectsock(int af, const char *host, const char *service,
-			    const char *protocol)
+                            const char *protocol)
 {
     struct protoent *ppe;
     struct addrinfo hints;
@@ -62,11 +62,11 @@ socket_t netlib_connectsock(int af, const char *host, const char *service,
     INVALIDATE_SOCKET(s);
     ppe = getprotobyname(protocol);
     if (strcmp(protocol, "udp") == 0) {
-	type = SOCK_DGRAM;
-	proto = (ppe) ? ppe->p_proto : IPPROTO_UDP;
+        type = SOCK_DGRAM;
+        proto = (ppe) ? ppe->p_proto : IPPROTO_UDP;
     } else {
-	type = SOCK_STREAM;
-	proto = (ppe) ? ppe->p_proto : IPPROTO_TCP;
+        type = SOCK_STREAM;
+        proto = (ppe) ? ppe->p_proto : IPPROTO_TCP;
     }
 
     /* we probably ought to pass this in as an explicit flag argument */
@@ -77,9 +77,9 @@ socket_t netlib_connectsock(int af, const char *host, const char *service,
     hints.ai_socktype = type;
     hints.ai_protocol = proto;
     if (bind_me)
-	hints.ai_flags = AI_PASSIVE;
+        hints.ai_flags = AI_PASSIVE;
     if ((ret = getaddrinfo(host, service, &hints, &result))) {
-	return NL_NOHOST;
+        return NL_NOHOST;
     }
 
     /*
@@ -93,45 +93,45 @@ socket_t netlib_connectsock(int af, const char *host, const char *service,
      * Thus, with the default parameters, we get IPv6 addresses first.
      */
     for (rp = result; rp != NULL; rp = rp->ai_next) {
-	ret = NL_NOCONNECT;
-	if ((s = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol)) < 0)
-	    ret = NL_NOSOCK;
-	else if (setsockopt
-		 (s, SOL_SOCKET, SO_REUSEADDR, (char *)&one,
-		  sizeof(one)) == -1) {
-	    ret = NL_NOSOCKOPT;
-	} else {
-	    if (bind_me) {
-		if (bind(s, rp->ai_addr, rp->ai_addrlen) == 0) {
-		    ret = 0;
-		    break;
-		}
-	    } else {
-		if (connect(s, rp->ai_addr, rp->ai_addrlen) == 0) {
-		    ret = 0;
-		    break;
-		}
-	    }
-	}
+        ret = NL_NOCONNECT;
+        if ((s = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol)) < 0)
+            ret = NL_NOSOCK;
+        else if (setsockopt
+                 (s, SOL_SOCKET, SO_REUSEADDR, (char *)&one,
+                  sizeof(one)) == -1) {
+            ret = NL_NOSOCKOPT;
+        } else {
+            if (bind_me) {
+                if (bind(s, rp->ai_addr, rp->ai_addrlen) == 0) {
+                    ret = 0;
+                    break;
+                }
+            } else {
+                if (connect(s, rp->ai_addr, rp->ai_addrlen) == 0) {
+                    ret = 0;
+                    break;
+                }
+            }
+        }
 
-	if (!BAD_SOCKET(s)) {
+        if (!BAD_SOCKET(s)) {
 #ifdef HAVE_WINSOCK2_H
-	  (void)closesocket(s);
+          (void)closesocket(s);
 #else
-	  (void)close(s);
+          (void)close(s);
 #endif
-	}
+        }
     }
     freeaddrinfo(result);
     if (ret != 0 || BAD_SOCKET(s))
-	return ret;
+        return ret;
 
 #ifdef IPTOS_LOWDELAY
     {
-	int opt = IPTOS_LOWDELAY;
-	(void)setsockopt(s, IPPROTO_IP, IP_TOS, &opt, sizeof(opt));
+        int opt = IPTOS_LOWDELAY;
+        (void)setsockopt(s, IPPROTO_IP, IP_TOS, &opt, sizeof(opt));
 #ifdef IPV6_TCLASS
-	(void)setsockopt(s, IPPROTO_IPV6, IPV6_TCLASS, &opt, sizeof(opt));
+        (void)setsockopt(s, IPPROTO_IPV6, IPV6_TCLASS, &opt, sizeof(opt));
 #endif
     }
 #endif
@@ -144,7 +144,7 @@ socket_t netlib_connectsock(int af, const char *host, const char *service,
      * for discussion.
      */
     if (type == SOCK_STREAM)
-	setsockopt(s, IPPROTO_TCP, TCP_NODELAY, (char *)&one, sizeof(one));
+        setsockopt(s, IPPROTO_TCP, TCP_NODELAY, (char *)&one, sizeof(one));
 #endif
 
     /* set socket to noblocking */
@@ -162,53 +162,53 @@ const char *netlib_errstr(const int err)
 {
     switch (err) {
     case NL_NOSERVICE:
-	return "can't get service entry";
+        return "can't get service entry";
     case NL_NOHOST:
-	return "can't get host entry";
+        return "can't get host entry";
     case NL_NOPROTO:
-	return "can't get protocol entry";
+        return "can't get protocol entry";
     case NL_NOSOCK:
-	return "can't create socket";
+        return "can't create socket";
     case NL_NOSOCKOPT:
-	return "error SETSOCKOPT SO_REUSEADDR";
+        return "error SETSOCKOPT SO_REUSEADDR";
     case NL_NOCONNECT:
-	return "can't connect to host/port pair";
+        return "can't connect to host/port pair";
     default:
-	return "unknown error";
+        return "unknown error";
     }
 }
 
-socket_t netlib_localsocket(const char *sockfile, int socktype)
 /* acquire a connection to an existing Unix-domain socket */
+socket_t netlib_localsocket(const char *sockfile, int socktype)
 {
 #ifdef HAVE_SYS_UN_H
     int sock;
 
     if ((sock = socket(AF_UNIX, socktype, 0)) < 0) {
-	return -1;
+        return -1;
     } else {
-	struct sockaddr_un saddr;
+        struct sockaddr_un saddr;
 
-	memset(&saddr, 0, sizeof(struct sockaddr_un));
-	saddr.sun_family = AF_UNIX;
-	(void)strlcpy(saddr.sun_path,
-		      sockfile,
-		      sizeof(saddr.sun_path));
+        memset(&saddr, 0, sizeof(struct sockaddr_un));
+        saddr.sun_family = AF_UNIX;
+        (void)strlcpy(saddr.sun_path,
+                      sockfile,
+                      sizeof(saddr.sun_path));
 
-	if (connect(sock, (struct sockaddr *)&saddr, SUN_LEN(&saddr)) < 0) {
-	    (void)close(sock);
-	    return -2;
-	}
+        if (connect(sock, (struct sockaddr *)&saddr, SUN_LEN(&saddr)) < 0) {
+            (void)close(sock);
+            return -2;
+        }
 
-	return sock;
+        return sock;
     }
 #else
     return -1;
 #endif /* HAVE_SYS_UN_H */
 }
 
-char *netlib_sock2ip(socket_t fd)
 /* retrieve the IP address corresponding to a socket */
+char *netlib_sock2ip(socket_t fd)
 {
     static char ip[INET6_ADDRSTRLEN];
 #ifdef HAVE_INET_NTOP
@@ -217,25 +217,24 @@ char *netlib_sock2ip(socket_t fd)
     socklen_t alen = (socklen_t) sizeof(fsin);
     r = getpeername(fd, &(fsin.sa), &alen);
     if (r == 0) {
-	switch (fsin.sa.sa_family) {
-	case AF_INET:
-	    r = !inet_ntop(fsin.sa_in.sin_family, &(fsin.sa_in.sin_addr),
-			   ip, sizeof(ip));
-	    break;
-#ifdef IPV6_ENABLE
-	case AF_INET6:
-	    r = !inet_ntop((int)fsin.sa_in6.sin6_family, &(fsin.sa_in6.sin6_addr),
-			   ip, sizeof(ip));
-	    break;
-#endif
-	default:
-	    (void)strlcpy(ip, "<unknown AF>", sizeof(ip));
-	    return ip;
-	}
+        switch (fsin.sa.sa_family) {
+        case AF_INET:
+            r = !inet_ntop(fsin.sa_in.sin_family, &(fsin.sa_in.sin_addr),
+                           ip, sizeof(ip));
+            break;
+        case AF_INET6:
+            r = !inet_ntop((int)fsin.sa_in6.sin6_family,
+                           &(fsin.sa_in6.sin6_addr), ip, sizeof(ip));
+            break;
+        default:
+            (void)strlcpy(ip, "<unknown AF>", sizeof(ip));
+            return ip;
+        }
     }
     /* Ugh... */
     if (r != 0)
 #endif /* HAVE_INET_NTOP */
-	(void)strlcpy(ip, "<unknown>", sizeof(ip));
+        (void)strlcpy(ip, "<unknown>", sizeof(ip));
     return ip;
 }
+// vim: set expandtab shiftwidth=4
