@@ -1,8 +1,11 @@
 /*
- * This file is Copyright (c) 2011 by Eckhart Wörner
+ * This file is Copyright 2011 by Eckhart Wörner
+ * This file is Copyright 2011 by the GPSD project
  * SPDX-License-Identifier: BSD-2-clause
  */
 
+#include "gpsd_config.h"  /* must be before all includes */
+
 #include <limits.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -31,3 +34,4 @@ int sd_get_socket_count(void) {
 
     return (int)n;
 }
+// vim: set expandtab shiftwidth=4
